/*
 * Copyright (C) 2018 Gravity Engineering Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.graveng.rci.server.config;

import java.util.HashMap;

import com.graveng.rci.util.Serializer;

/**
 * 全てのRCIサーバの設定情報を保持する
 */
public class Config extends Serializer {

	/**
	 * RCIサーバの設定情報
	 */
	protected ServerConfig serverConfig = new ServerConfig();

	/**
	 * 許可IPアドレスの設定情報
	 * key:IPアドレス、value:IpAddressConfig
	 */
	protected HashMap<String, IpAddressConfig> ipAddressAllowFilter = new HashMap<String, IpAddressConfig>();

	/**
	 * 拒否IPアドレスの設定情報
	 *  key:IPアドレス、value:IpAddressConfig
	 */
	protected HashMap<String, IpAddressConfig> ipAddressDenyFilter = new HashMap<String, IpAddressConfig>();

	/**
	 * ユーザ管理情報
	 *  key:ユーザ名、value:UserConfig
	 */
	protected HashMap<String, UserConfig> userNameFilter = new HashMap<String, UserConfig>();

	/**
	 * グループ管理情報
	 *  key:グループ名、value:GroupConfig
	 */
	protected HashMap<String, GroupConfig> groupFilter = new HashMap<String, GroupConfig>();

	public Config() {

	}

	public Config(boolean isInit) {
		if(isInit) {
			setupExample();
		}
	}

	protected void setupExample() {
		// 変数が初期値と違いがないとXMLEncoderはファイルに出力しないため敢えてここで設定してからファイル出力する。
	}

	public ServerConfig getServerConfig() {
		return serverConfig;
	}

	public void setServerConfig(ServerConfig serverConfig) {
		this.serverConfig = serverConfig;
	}

	public HashMap<String, UserConfig> getUserNameFilter() {
		return userNameFilter;
	}

	public void setUserNameFilter(HashMap<String, UserConfig> userNameFilter) {
		this.userNameFilter = userNameFilter;
	}

	public HashMap<String, IpAddressConfig> getIpAddressAllowFilter() {
		return ipAddressAllowFilter;
	}

	public void setIpAddressAllowFilter(HashMap<String, IpAddressConfig> ipAddressAllowFilter) {
		this.ipAddressAllowFilter = ipAddressAllowFilter;
	}

	public HashMap<String, IpAddressConfig> getIpAddressDenyFilter() {
		return ipAddressDenyFilter;
	}

	public void setIpAddressDenyFilter(HashMap<String, IpAddressConfig> ipAddressDenyFilter) {
		this.ipAddressDenyFilter = ipAddressDenyFilter;
	}

	public HashMap<String, GroupConfig> getGroupFilter() {
		return groupFilter;
	}

	public void setGroupFilter(HashMap<String, GroupConfig> groupFilter) {
		this.groupFilter = groupFilter;
	}

}
