/*
 * Copyright (C) 2018 Gravity Engineering Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.graveng.rci.server.config;

import java.util.HashMap;

import com.graveng.rci.util.Serializer;

/**
 * ユーザ情報
 */
public class UserConfig extends Serializer{

	/**
	 * ログインユーザ名
	 */
	protected String name;

	/**
	 * （ハッシュ化された）パスワード
	 */
	protected String password;

	/**
	 * 所属グループ(ディレクトリ)名
	 */
	protected String group = "";

	/**
	 * パスワードのハッシュアルゴリズム名
	 */
	protected String hashAlgorithmName = "SHA-256";

	/**
	 * 設定ファイル登録時のハッシュ化回数
	 */
	protected int passwordRegistHashRoundCount = 1;

	/**
	 * ログイン認証時にサーバが受け取るパスワードのハッシュ化回数
	 */
	protected int passwordAuthHashRoundCount = 2;

	/**
	 * 公開鍵（一致検証用）
	 */
	protected String publicKey;

	/**
	 * パッケージ名の拒否情報<br>
	 * key:パッケージ名、value:コメント相当
	 */
	protected HashMap<String, String> packageDenyFilter = new HashMap<String, String>();

	/**
	 * パッケージ名の許可情報<br>
	 * key:パッケージ名、value:コメント相当
	 */
	protected HashMap<String, String> packageAllowFilter = new HashMap<String, String>();

	/**
	 * クラス名のフィルター情報<br>
	 * key:クラス名、value:メソッド名, コメント相当
	 */
	protected HashMap<String, HashMap<String, String>> classNameFilter = new HashMap<String, HashMap<String, String>>();

	/**
	 * sudoのように別のユーザとしてログインするためのもの。（未実装）
	 */
	protected HashMap<String, String> childFilter = new HashMap<String, String>();

	public HashMap<String, String> getPackageDenyFilter() {
		return packageDenyFilter;
	}

	public void setPackageDenyFilter(HashMap<String, String> packageDenyFilter) {
		this.packageDenyFilter = packageDenyFilter;
	}

	public HashMap<String, String> getPackageAllowFilter() {
		return packageAllowFilter;
	}

	public void setPackageAllowFilter(HashMap<String, String> packageAllowFilter) {
		this.packageAllowFilter = packageAllowFilter;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public HashMap<String, String> getChildFilter() {
		return childFilter;
	}

	public void setChildFilter(HashMap<String, String> childFilter) {
		this.childFilter = childFilter;
	}

	public String getGroup() {
		return group;
	}

	public void setGroup(String group) {
		this.group = group;
	}

	public String getPublicKey() {
		return publicKey;
	}

	public void setPublicKey(String publicKey) {
		this.publicKey = publicKey;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getHashAlgorithmName() {
		return hashAlgorithmName;
	}

	public void setHashAlgorithmName(String hashAlgorithmName) {
		this.hashAlgorithmName = hashAlgorithmName;
	}

	public int getPasswordRegistHashRoundCount() {
		return passwordRegistHashRoundCount;
	}

	public void setPasswordRegistHashRoundCount(int passwordRegistHashRoundCount) {
		this.passwordRegistHashRoundCount = passwordRegistHashRoundCount;
	}

	public int getPasswordAuthHashRoundCount() {
		return passwordAuthHashRoundCount;
	}

	public void setPasswordAuthHashRoundCount(int passwordAuthHashRoundCount) {
		this.passwordAuthHashRoundCount = passwordAuthHashRoundCount;
	}

	public HashMap<String, HashMap<String, String>> getClassNameFilter() {
		return classNameFilter;
	}

	public void setClassNameFilter(HashMap<String, HashMap<String, String>> classNameFilter) {
		this.classNameFilter = classNameFilter;
	}


}
