/*
 * Copyright (C) 2018 Gravity Engineering Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.graveng.rci.util;

//import java.lang.reflect.Field;
import java.util.HashMap;

/**
 * 文字列に関するユーティリティ
 */
public class StringUtils {

	/**
	 * nullか空文字列か判定する。
	 * @param text 文字列
	 * @return nullか空文字列ならtrue
	 */
	public static boolean isEmpty(String text) {
		if(text == null) {
			return true;
		}
		if(text.length() == 0) {
			return true;
		}
		return false;
	}

	/**
	 * "-a avalue -b bvalue"形式のオプション指定をkey:"-a", value:"avalue"形式のMapで返す
	 * @param args mainのargs
	 * @return オプションの次の文字列を格納したHashMap
	 */
	public static HashMap<String, String> getOptions(String[] args) {
		HashMap<String, String> result = new HashMap<String, String>();
		for(int i = 0; i < args.length; i++) {
			if(args[i].startsWith("-")) {
				if(i+1 < args.length && !args[i+1].startsWith("-")) {
					result.put(args[i], args[i+1]);
					i++;
				}
			}
		}
		return result;
	}

	/**
	 * 分割文字で区切られて最後の文字列を切り捨てた文字列を返す
	 * text:"192.168.3.2", separator:"."なら、"192.168.3"を返す
	 * @param text 切り出し前文字列
	 * @param separator 分割文字
	 * @return 切り捨てた文字列
	 */
	public static String getSeparatorParent(String text, String separator ) {
		int lastIndex = text.lastIndexOf(separator);
		if(lastIndex < 0) {
			return "";
		}
		return text.substring(0, lastIndex);
	}
}
